.. _contributing:

Contributing
============

If you already have an idea for a feature you'd like to see in *scikit-hep*,
you can start by seeing how to :ref:`contribute code <contributing_code>`.
If not, we have :ref:`plenty of ideas <ideas>` we'd love to see materialising!

BTW, check also the :ref:`affiliated packages <affiliations>` as your must-have feature could already exist there ...

.. _contributing_code:

Contributing code
-----------------

The Scikit-HEP project is community-driven and community-oriented.
As such, we welcome contributions and contributors from all horizons,
provided they comply with the
`Python Community Code of Conduct <https://www.python.org/psf/codeofconduct/>`_.


Coding guidelines
~~~~~~~~~~~~~~~~~

Guidelines for coding and documentation are under development.


Suggesting new functionality
----------------------------

First check that the functionality does not already exist in :ref:`the API <api>`.


Project ideas
-------------

A dedicated page is available as a :ref:`forum for project ideas <ideas>`.


Feedback and bug reporting
--------------------------

For now please provide feedback and/or report bugs via the
`GitHub Issues <https://github.com/scikit-hep/scikit-hep/issues>`_ page.
